/*
 *  ----------------------------------------------------------------------------
 *  Filename      : HelpPanel.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 10.10.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.Hashtable;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ScrollPaneConstants;
import javax.swing.UIManager;

import ch.educeth.soekia.util.HtmlPanel;

/**
 * HelpPanel.
 *
 * @author	Matthias Dreier
 */
public class HelpPanel extends JPanel implements MouseListener {

	/**
	 * The color of the background.
	 */
	protected Color backgroundColor;

	/**
	 * The color of the links.
	 */
	protected Color linkColor;

	/**
	 * The navigation panel.
	 */
	protected JPanel navigationPanel; 

	/**
	 * The table containing the file names of the help pages.
	 */
	protected Hashtable pages;

	/**
	 * The html panel for the help pages.
	 */
	protected HtmlPanel htmlPanel;

	/**
	 * Create a new HelpPanel using the given colors.
	 *
	 * @param	backgroundColor		The color of the background.
	 * @param	linkColor			The color of the links.
	 */
	public HelpPanel(Color backgroundColor, Color linkColor) {
		this.backgroundColor = backgroundColor;
		this.linkColor = linkColor;
		pages = new Hashtable();
		createGUI();
	}

	/**
	 * Creates the GUI components.
	 */
	protected void createGUI() {
		setLayout(new BorderLayout());
		setPreferredSize(new Dimension(600, 400));

		navigationPanel = new JPanel();
		navigationPanel.setLayout(new BoxLayout(navigationPanel, BoxLayout.X_AXIS));
		navigationPanel.setBackground(backgroundColor);
		add(navigationPanel, BorderLayout.NORTH);

		htmlPanel = new HtmlPanel();
		JScrollPane scrollPane = new JScrollPane(htmlPanel, ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED,ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		add(scrollPane, BorderLayout.CENTER);
	}

	/**
	 * Creates a new navigation label with the given text and adds the MouseListener.
	 *
	 * @param	text	The text for the label.
	 * @return	The new navigation label.
	 */
	protected JLabel createLabel(String text) {
		JLabel label = new JLabel(text);
		label.addMouseListener(this);
		label.setBackground(backgroundColor);
		label.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		label.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
		label.setFont(new Font("Dialog", Font.PLAIN, 18));
		label.setForeground(linkColor);
		label.setOpaque(true);

		return label;
	}

	/**
	 * Adds a new page to the HelpPanel with given title and help file.
	 *
	 * @param	title	The title of the new page.
	 * @param	helpFile	The help file for the new page.
	 */
	public void addPage(String title, String helpFile) {
		JLabel label = createLabel(title);
		if (pages.size() == 0) {
			label.setBackground(UIManager.getColor("Label.background"));
		}
		pages.put(title, helpFile);
		navigationPanel.add(label);
		navigationPanel.revalidate();
	}

	/**
	 * Shows the page in the HelpPanel.
	 *
	 * @param	title	The title of the page.
	 */
	public void showPage(String title) {
		htmlPanel.showFile((String)pages.get(title));
		revalidate();
	}

	public void mouseClicked(MouseEvent e) {
		if (e.getSource() instanceof JLabel) {
			htmlPanel.showFile((String)pages.get(((JLabel)e.getSource()).getText()));
			Component[] components = navigationPanel.getComponents();
			for (int i = 0; i < components.length; i++) {
				components[i].setBackground(backgroundColor);
			}
			((JLabel)e.getSource()).setBackground(UIManager.getColor("Label.background"));
			revalidate();
		}
	}

	public void mousePressed(MouseEvent e) {}

	public void mouseReleased(MouseEvent e) {}

	public void mouseEntered(MouseEvent e) {}

	public void mouseExited(MouseEvent e) {}

}
