/*
 *  ----------------------------------------------------------------------------
 *  Filename      : IndexTask.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 11.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.index;

import ch.educeth.soekia.Application;
import ch.educeth.soekia.util.SwingWorker;

/**
 * IndexTask.
 *
 * @author	Matthias Dreier
 */
public class IndexTask {

	/**
	 * The current percentage of the progress.
	 */
	protected int current;

	/**
	 * The current status status of the task.
	 */
	protected String status;

	/**
	 * The application for this task.
	 */
	protected Application application;

	/**
	 * Creates a new index task.
	 *
	 * @param	application	The application.
	 */
	public IndexTask(Application application) {
		current = 0;
		this.application = application;
	}

	/**
	 * Returns whether the task is done.
	 *
	 * @return		<code>true</code> if the percentage of the progress is 100,
	 * 				otherwise <code>false</code>.
	 */
	public boolean done() {
		return (current == 100);
	}

	/**
	 * Returns the current percentage of the progress.
	 *
	 * @return		The current percentage of the progress.
	 */
	public int getCurrent() {
		return current;
	}

	/**
	 * Returns the current status of the task.
	 *
	 * @return		The current status of the task.
	 */
	public String getStatus() {
		return status;
	}

	/**
	 * Starts the SwingWorker.
	 */
	public void go() {
		current = 0;
		final SwingWorker worker = new SwingWorker() {
			public Object construct() {
				return new IndexThread(application, IndexTask.this);
			}
		};
		worker.start();
	}

}
