/*
 *  ----------------------------------------------------------------------------
 *  Filename      : AnalyzerFactory.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 11.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.lucene;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.standard.StandardAnalyzer;

/**
 * AnalyzerFactory.
 *
 * @author	Matthias Dreier
 */
public abstract class AnalyzerFactory {

	/**
	 * Creates a new analyzer for the given language.
	 *
	 * @param	language			The language for the analyzer.
	 * @param	doStemming			The flag whether to do stemming.
	 * @param	removeStopWords		The flag whether to remove the stop words.
	 * @param	stopWords			The string containing the stopWords.
	 *
	 * @return		A new analyzer for the given language.
	 */
	public static Analyzer createAnalyzer(String language, boolean doStemming, boolean removeStopWords, String stopWords) {
		if (language.equals("English")) {
			return new EnglishAnalyzer(doStemming, removeStopWords, stopWords);
		} else if (language.equals("German")) {
			return new DeutschAnalyzer(doStemming, removeStopWords, stopWords);
		} else {
			System.err.println("Unknow language: " + language);
			return new StandardAnalyzer();
		}
	}

}
