/*
 *  ----------------------------------------------------------------------------
 *  Filename      : DeutschStemFilter.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 30.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.lucene;

import java.io.IOException;

import org.apache.lucene.analysis.Token;
import org.apache.lucene.analysis.TokenFilter;
import org.apache.lucene.analysis.TokenStream;

/**
 * DeutschStemFilter.
 *
 * @author	Matthias Dreier
 */
public class DeutschStemFilter extends TokenFilter {

	/**
	 * The stemmer for this filter.
	 */
	protected StemmerInterface stemmer;

	/**
	 * Creates a new DeutschStemFilter for the given token stream.
	 *
	 * @param	in	The token stream.
	 */
	public DeutschStemFilter(TokenStream in, StemmerInterface stemmer) {
		this.stemmer = stemmer;
		input = in;
	}

	public Token next() throws IOException {
		Token t = input.next();
		if (t == null) {
			return null;
		}

		return new Token(stemmer.stem(t.termText()), t.startOffset(), t.endOffset(), t.type());
	}

}
