/*
 *  ----------------------------------------------------------------------------
 *  Filename      : DeutschStemmer.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 30.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.lucene;

/**
 * A simple stemming algorithm for German.
 *
 * @author	Matthias Dreier
 */
public class DeutschStemmer implements StemmerInterface {

	public String stem(String word) {
		word = replaceDiphthongs(word);
		word = removePrefix(word);
		word = removeSuffix(word);
		word = removeSuffix(word);
		word = removeSuffix(word);
		word = removeSuffix(word);
		word = word.toLowerCase();

		return word;
	}

	/**
	 * Removes the most frequent German prefixes.
	 *
	 * @param	term	The term.
	 *
	 * @return			The term without prefix.
	 */
	protected String removePrefix(String term) {
		String str = term.toString();
		str = str.replaceAll("^(ent|ge|un|ver)(?=(...))", "");

		if (str.length() < 3) {
			return term;
		} else {
			return str;
		}
	}

	/**
	 * Removes the most frequent German suffixes.
	 *
	 * @param	term	The term.
	 *
	 * @return			The term without suffix.
	 */
	protected String removeSuffix(String term) {
		String str = term.toString();
		str = str.replaceAll("(?<=[elr])nd$" +
			"|((i|l?un)(g|n))$" +
			"|(lich|s)$" +
			"|((e|ba)r|lich|ig)?(e[mnrs]?)?$" +
			"|(?<=(....))(?<![aeiou])n$" +
			"|(inn|l?ung)en$" +
			"|(?<=t)ion(en)?$" +
			"|(((h|k)EI)|(e|(e?s)))t$", "");

		if (str.length() < 3) {
			return term;
		} else {
			return str;
		}
	}

	/**
	 * Replaces some German diphthongs.
	 *
	 * @param	term	The term.
	 *
	 * @return			The term without diphthongs.
	 */
	protected String replaceDiphthongs(String term) {
		term = term.replaceAll("ei", "EI");
		term = term.replaceAll("ie", "IE");
		term = term.replaceAll("ss", "SS");

		return term;
	}

}
