/*
 *  ----------------------------------------------------------------------------
 *  Filename      : ScrollablePanel.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 10.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.util;

import java.awt.Dimension;
import java.awt.Rectangle;

import javax.swing.JPanel;
import javax.swing.Scrollable;


/**
 * ScrollablePanel.
 *
 * @author	Matthias Dreier
 */
public class ScrollablePanel extends JPanel implements Scrollable {

	/**
	 * The increment value for one block.
	 */
	protected int blockIncrement;

	/**
	 * The increment value for one unit.
	 */
	protected int unitIncrement;

	/**
	 * Create a new ScrollablePanel with default unit and block increment.
	 */
	public ScrollablePanel() {
		blockIncrement = 25;
		unitIncrement = 5;
	}

	/**
	 * Creates a new ScrollablePanel with given unit increment and block increment.
	 *
	 * @param	unitIncrement	The value for unit increment.
	 * @param	blockIncrement	The value for block increment.
	 */
	public ScrollablePanel(int unitIncrement, int blockIncrement) {
		this.blockIncrement = blockIncrement;
		this.unitIncrement = unitIncrement;
	}

	public Dimension getPreferredScrollableViewportSize() {
		return getPreferredSize();
	}

	public int getScrollableUnitIncrement(Rectangle arg0, int arg1, int arg2) {
		return unitIncrement;
	}

	public int getScrollableBlockIncrement(Rectangle arg0, int arg1, int arg2) {
		return blockIncrement;
	}

	public boolean getScrollableTracksViewportWidth() {
		return false;
	}

	public boolean getScrollableTracksViewportHeight() {
		return false;
	}

}
