/*
 *  ----------------------------------------------------------------------------
 *  Filename      : XmlExporter.java
 *  ----------------------------------------------------------------------------
 *  Application   : Soekia
 *  Author        : Matthias Dreier
 *  File created  : 16.09.2003
 *  ----------------------------------------------------------------------------
 *  This file is part of Soekia.
 *
 *  Soekia is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Soekia is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Soekia; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  ----------------------------------------------------------------------------
 */
package ch.educeth.soekia.xml;

import java.io.File;
import java.io.FileWriter;

/**
 * An XML exporter for settings.
 *
 * @author	Matthias Dreier
 */
public class XmlExporter {

	/**
	 * Exports the settings to the given file.
	 *
	 * @param	settings	The settings.
	 * @param	file		The file.
	 *
	 * @return				<code>true</code> if the settings were exported
	 * 						successfully, otherwise <code>false</code>.
	 */
	public boolean exportSettings(Settings settings, File file) {
		try {
			FileWriter out = new FileWriter(file);

			out.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n\n");
			out.write("<settings>\n");
			out.write("  <name>" + settings.getName() + "</name>\n");

			for (int i = 0; i < settings.getNumberSettings(); i++) {
				out.write("  <setting>\n");
				Setting setting = settings.getSetting(i);
				out.write("    <name>" + setting.name + "</name>\n");
				for (int j = 0; j < setting.values.size(); j++) {
					String value = (String)setting.values.get(j);
					out.write("    <value>" + value + "</value>\n");
				}
				out.write("  </setting>\n");
			}

			out.write("</settings>\n");
			out.close();
			return true;
		} catch (Exception ex) {
			return false;
		}
	}

}
